# AquaCrop-OSPy

Soil-Crop-Water model based on AquaCrop-OS.

This is adapted from the original AquaCrop-OS model, which is [a crop growth model developed by FAO](https://github.com/aquacropos/aquacrop).
Based on 3.0.7 version and made some modifications on deprecated warnings.
